@@ -10,11 +10,11 @@ import stat
 import tempfile
 import unittest
 
+import josepy as jose
 import mock
 import six
 
 from acme import challenges
-from acme import jose
 
 from certbot import achallenges
 from certbot import errors
